From 977f8a30103b9c4992cab8f49357fe0d4274004f Mon Sep 17 00:00:00 2001
From: Jonas Gorski <jonas.gorski@gmail.com>
Date: Thu, 3 May 2012 14:55:26 +0200
Subject: [PATCH 69/80] MIPS: BCM63XX: pass caldata info to flash

---
 arch/mips/bcm63xx/boards/board_common.c              |    2 +-
 arch/mips/bcm63xx/dev-flash.c                          |    9 ++++++++-
 arch/mips/include/asm/mach-bcm63xx/bcm63xx_dev_flash.h |    4 +++-
 3 files changed, 12 insertions(+), 3 deletions(-)

--- a/arch/mips/bcm63xx/boards/board_common.c
+++ b/arch/mips/bcm63xx/boards/board_common.c
@@ -269,7 +269,7 @@ int __init board_register_devices(void)
 	if (board.num_spis)
 		spi_register_board_info(board.spis, board.num_spis);
 
-	bcm63xx_flash_register();
+	bcm63xx_flash_register(board.has_caldata, board.caldata);
 
 	/* count number of LEDs defined by this device */
 	while (led_count < ARRAY_SIZE(board.leds) && board.leds[led_count].name)
--- a/arch/mips/bcm63xx/dev-flash.c
+++ b/arch/mips/bcm63xx/dev-flash.c
@@ -38,12 +38,15 @@ static struct mtd_partition mtd_partitio
 	}
 };
 
+static struct mtd_part_parser_data bcm63xx_parser_data;
+
 static const char *bcm63xx_part_types[] = { "bcm63xxpart", "RedBoot", NULL };
 
 static struct physmap_flash_data flash_data = {
 	.width			= 2,
 	.parts			= mtd_partitions,
 	.part_probe_types	= bcm63xx_part_types,
+	.pp_data		= &bcm63xx_parser_data,
 };
 
 static struct resource mtd_resources[] = {
@@ -71,6 +74,7 @@ void __init bcm63xx_flash_force_phys_bas
 
 static struct flash_platform_data bcm63xx_flash_data = {
 	.part_probe_types	= bcm63xx_part_types,
+	.pp_data		= &bcm63xx_parser_data,
 };
 
 static struct spi_board_info bcm63xx_spi_flash_info[] = {
@@ -211,9 +215,13 @@ void __init bcm63xx_flash_detect(void)
 	}
 }
 
-int __init bcm63xx_flash_register(void)
+int __init bcm63xx_flash_register(int num_caldata, struct ath9k_caldata *caldata)
 {
 	u32 val;
+	unsigned int i;
+
+	for (i = 0; i < num_caldata; i++)
+		bcm63xx_parser_data.caldata[i] = caldata[i].caldata_offset;
 
 	switch (flash_type) {
 	case BCM63XX_FLASH_TYPE_PARALLEL:
--- a/arch/mips/include/asm/mach-bcm63xx/bcm63xx_dev_flash.h
+++ b/arch/mips/include/asm/mach-bcm63xx/bcm63xx_dev_flash.h
@@ -1,6 +1,8 @@
 #ifndef __BCM63XX_FLASH_H
 #define __BCM63XX_FLASH_H
 
+#include <board_bcm963xx.h>
+
 enum {
 	BCM63XX_FLASH_TYPE_PARALLEL,
 	BCM63XX_FLASH_TYPE_SERIAL,
@@ -11,7 +13,7 @@ void bcm63xx_flash_detect(void);
 
 void bcm63xx_flash_force_phys_base_address(u32 start, u32 end);
 
-int __init bcm63xx_flash_register(void);
+int __init bcm63xx_flash_register(int num_caldata, struct ath9k_caldata *caldata);
 
 int bcm63xx_flash_get_type(void);
 
